@@ -2,11 +2,12 @@
 
 __author__ = """Yossi Mosbacher"""
 __email__ = 'joe.mosbacher@gmail.com'
-__version__ = '0.4.6'
+__version__ = '0.4.8'
 
 # import eve_panel
-from . import api
-from .api.app import list_roles
+from xepmts import api
+from xepmts.api.server.v1.app import list_roles
+from xepmts.api.server.v1.client import default_client
 
 def settings(**kwargs):
     from eve_panel import settings as panel_settings
@@ -16,9 +17,9 @@ def settings(**kwargs):
         for k,v in kwargs.items():
             setattr(panel_settings, k, v)
 
-def default_client():
-    from xepmts.api.client import default_client
-    return default_client()
+# def default_client():
+    
+#     return default_client()
 
 def extension():
     import eve_panel
